[dpdk-dev] [PATCH 1/1] tools: Fix some strings and functions regarding VFIO support

Andre Richter andre.o.richter at gmail.com
Mon Mar 23 13:06:25 CET 2015


This patch fixes several minor issues in setup.sh:

     - show_nics() would not display the current Ethernet settings if
       the user only loads the vfio-pci module, b/c it only checks for
       presence of igb_uio. Fix this by adding a check for vfio-pci.

     - unbind_nics(): Fix option naming and string inside function.

     - Exchange a forgotten "igb_uio" with "vfio-pci" in a comment.

Signed-off-by: Andre Richter <andre.o.richter at gmail.com>
---
 tools/setup.sh | 12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/tools/setup.sh b/tools/setup.sh
index ac438c2..5a8b2f3 100755
--- a/tools/setup.sh
+++ b/tools/setup.sh
@@ -427,16 +427,16 @@ grep_meminfo()
 #
 show_nics()
 {
-	if  /sbin/lsmod  | grep -q igb_uio ; then
+	if  /sbin/lsmod | grep -q -e igb_uio -e vfio_pci; then
 		${RTE_SDK}/tools/dpdk_nic_bind.py --status
 	else
-		echo "# Please load the 'igb_uio' kernel module before querying or "
-		echo "# adjusting NIC device bindings"
+		echo "# Please load the 'igb_uio' or 'vfio-pci' kernel module before "
+		echo "# querying or adjusting NIC device bindings"
 	fi
 }
 
 #
 # Uses dpdk_nic_bind.py to move devices to work with igb_uio
 #
 bind_nics_to_vfio()
 {
@@ -477,7 +477,7 @@ unbind_nics()
 {
 	${RTE_SDK}/tools/dpdk_nic_bind.py --status
 	echo ""
-	echo -n "Enter PCI address of device to bind to IGB UIO driver: "
+	echo -n "Enter PCI address of device to unbind: "
 	read PCI_PATH
 	echo ""
 	echo -n "Enter name of kernel driver to bind the device to: "
@@ -574,7 +574,7 @@ step5_func()
 	TEXT[1]="Uninstall all targets"
 	FUNC[1]="uninstall_targets"
 
-	TEXT[2]="Unbind NICs from IGB UIO driver"
+	TEXT[2]="Unbind NICs from IGB UIO or VFIO driver"
 	FUNC[2]="unbind_nics"
 
 	TEXT[3]="Remove IGB UIO module"
@@ -427,16 +427,16 @@ grep_meminfo()
 
 #
-# Uses dpdk_nic_bind.py to move devices to work with igb_uio
+# Uses dpdk_nic_bind.py to move devices to work with vfio-pci
 #
 bind_nics_to_vfio()
-- 
1.9.1



More information about the dev mailing list